<?php
/**
 * @package     Joomla.Site
 * @subpackage  Templates.protostar
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 */
defined('_JEXEC') or die;
/**
 * This is a file to add template specific chrome to module rendering.  To use it you would
 * set the style attribute for the given module(s) include in your template to use the style
 * for each given modChrome function.
 *
 * eg. To render a module mod_test in the submenu style, you would use the following include:
 * <jdoc:include type="module" name="test" style="submenu" />
 *
 * This gives template designers ultimate control over how modules are rendered.
 *
 * NOTICE: All chrome wrapping methods should be named: modChrome_{STYLE} and take the same
 * two arguments.
 */
/*
 * Module chrome for rendering the module in a submenu
 */
function modChrome_no($module, &$params, &$attribs)
{
    if ($module->content) {
        echo $module->content;
    }
}

function modChrome_header($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<' . $moduleTag . ' class="ok-subheader' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        echo $module->content;
        echo '</' . $moduleTag . '>';
    }
}

function modChrome_well($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<' . $moduleTag . ' class="well ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
        }
        echo $module->content;
        echo '</' . $moduleTag . '>';
    }
}

function modChrome_clean($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<' . $moduleTag . ' class="uk-panel ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
        }
        echo $module->content;
        echo '</' . $moduleTag . '>';
    }
}

function modChrome_box($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title-boxed ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
        echo '<' . $moduleTag . ' class="uk-panel uk-panel-box ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';}
        echo $module->content;
        echo '</' . $moduleTag . '>';
    }
}

function modChrome_ok1($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<div class="uk-width-medium-1-1">';
        echo '<' . $moduleTag . ' class="uk-panel ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
        }
        echo $module->content;
        echo '</' . $moduleTag . '>';
        echo '</div>';
    }
}

function modChrome_ok2($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<div class="uk-width-medium-1-2">';
        echo '<' . $moduleTag . ' class="uk-panel ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
        }
        echo $module->content;
        echo '</' . $moduleTag . '>';
        echo '</div>';
    }
}



function modChrome_ok3($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<div class="uk-width-medium-1-3">';
        echo '<' . $moduleTag . ' class="uk-panel ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
        }
        echo $module->content;
        echo '</' . $moduleTag . '>';
        echo '</div>';
    }
}



function modChrome_ok4($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<div class="uk-width-medium-1-4">';
        echo '<' . $moduleTag . ' class="uk-panel ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
        }
        echo $module->content;
        echo '</' . $moduleTag . '>';
        echo '</div>';
    }
}

function modChrome_ok1box($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<div class="uk-width-medium-1-1">';
echo '<' . $moduleTag . ' class="uk-panel uk-panel-box ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title-boxed ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';
        }
        echo $module->content;
        echo '</' . $moduleTag . '>';
        echo '</div>';
    }
}

function modChrome_ok2box($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<div class="uk-width-medium-1-2">';
      echo '<' . $moduleTag . ' class="uk-panel uk-panel-box ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title-boxed ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';}
        echo $module->content;
        echo '</' . $moduleTag . '>';
        echo '</div>';
    }
}

function modChrome_ok3box($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<div class="uk-width-medium-1-3">';
 echo '<' . $moduleTag . ' class="uk-panel uk-panel-box ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title-boxed ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';}
            echo $module->content;
        echo '</' . $moduleTag . '>';
        echo '</div>';
    }
}

function modChrome_ok4box($module, &$params, &$attribs)
{
    $moduleTag = $params->get('module_tag', 'div');
    $bootstrapSize = (int)$params->get('bootstrap_size', 0);
    $moduleClass = $bootstrapSize != 0 ? ' span' . $bootstrapSize : '';
    $headerTag = htmlspecialchars($params->get('header_tag', 'h3'));
    $headerClass = htmlspecialchars($params->get('header_class', 'page-header'));
    if ($module->content) {
        echo '<div class="uk-width-medium-1-4">';
        echo '<' . $moduleTag . ' class="uk-panel uk-panel-box ' . htmlspecialchars($params->get('moduleclass_sfx')) . $moduleClass . '">';
        if ($module->showtitle) {
            echo '<' . $headerTag . ' class="uk-panel-title-boxed ' . $headerClass . '">' . $module->title . '</' . $headerTag . '>';}
       echo $module->content;
        echo '</' . $moduleTag . '>';
        echo '</div>';
    }
}