<?php
/**
 * @package     Joomla.Platform
 * @subpackage  Form
 *
 * @copyright   Copyright (C) 2005 - 2015 Open Source Matters, Inc. All rights reserved.
 * @license     GNU General Public License version 2 or later; see LICENSE
 */

defined('JPATH_PLATFORM') or die;

/**
 * Form Field class for the Joomla Platform.
 * Display a JSON loaded window with a repeatable set of sub fields
 *
 * @since  3.2
 */
class JFormFieldOkmodal extends JFormField
{

    /**
     * The form field type.
     *
     * @var    string
     * @since  3.2
     */
    protected $type = 'Okmodal';

    /**
     * Method to get the field input markup.
     *
     * @return  string  The field input markup.
     *
     * @since   3.2
     */

    public function getLabel() {

        return '<span>' . parent::getLabel() . '</span>';
    }


    protected function getInput()
    {
        //  Additional files
        $path = 'templates/orion_nebula/css/';
        JHTML::_('stylesheet', $path . 'admin.css');


        // Initialize variables.
        $subForm = new JForm($this->name, array('control' => 'jform'));
        $xml = $this->element->children()->asXml();
        $subForm->load($xml);

        // Needed for repeating modals in gmaps
        // @TODO: what and where???
        $subForm->repeatCounter = (int)@$this->form->repeatCounter;

        $children = $this->element->children();
        $subForm->setFields($children);

        // If a maximum value isn't set then we'll make the maximum amount of cells a large number
        $maximum = $this->element['maximum'] ? (int)$this->element['maximum'] : '999';

        // Build a Table
        $head_row_str = array();
        $body_row_str = array();
        foreach ($subForm->getFieldset() as $field) {
            // Reset name to simple
            $field->name = (string)$field->element['name'];

            // Build heading

//            $head_row_str[] = '</div  class="span12 test">';
            $head_row_str[] = '<div class="span9 ok-modal">';
            $head_row_str[] = '<div class="ok-panel-title span3 ">' . strip_tags($field->getLabel($field->name)) .'</div>';;
            $head_row_str[] = '<div class="ok-panel-input span6 ">' . $field->getInput() . '</div>';
            $head_row_str[] = '</div>';



        }


        // Put all table parts together
        $table = '<table>'
            . '<tr>'
            . '<td id="' . $this->id . '_table" class="adminlist ' . $this->element['class'] . ' table table-striped">' . implode("\n", $head_row_str) . '</td>'
            . '</tr>'
            . '</table>';


        // And finaly build a main container
        $str = array();
        $str[] = '<div id="' . $this->id . '_container">';

        // Add the table to modal
        $str[] = '<div id="' . $this->id . '_modal" class="modal hide fade">';
        $str[] = '<div class="modal-header">
            <h3 id="myModalLabel">' . JText::_($this->element['label']) . '</h3>
          </div>';
        $str[] = $table;
        $str[] = '<div class="modal-footer">';
        $str[] = '<button class="close-modal btn button btn-link">' . JText::_('JCANCEL') . '</button>';
        $str[] = '<button class="save-modal-data btn button btn-primary">' . JText::_('JAPPLY') . '</button>';
        $str[] = '</div>';

        // Close modal container
        $str[] = '</div>';

        // Close main container
        $str[] = '</div>';

        // Button for display the modal window ***********************************************************************************************
        $label = JText::_($this->element['label']); // dev but name
        $description = JText::_($this->element['description']); // dev but name
        $icon = $this->element['icon'] ? '<span class="icon-' . $this->element['icon'] . '"></span> ' : '';
        $str[] = '<div class="ok-admin-pannel" id="' . $this->id . '_button" >
        <span class="ok-admin-field-label">' . $icon . $label . '</span>
        <span class="ok-admin-field-descr">' . $description . '</span>
        </div>';

        if (is_array($this->value)) {
            $this->value = array_shift($this->value);
        }

        // Script params
        $data = array();
        $data[] = 'data-container="#' . $this->id . '_container"';
        $data[] = 'data-modal-element="#' . $this->id . '_modal"';
        $data[] = 'data-repeatable-element="table tbody tr"';
        $data[] = 'data-bt-add="a.add"';
        $data[] = 'data-bt-remove="a.remove"';
        $data[] = 'data-bt-modal-open="#' . $this->id . '_button"';
        $data[] = 'data-bt-modal-close="button.close-modal"';
        $data[] = 'data-bt-modal-save-data="button.save-modal-data"';
        $data[] = 'data-maximum="' . $maximum . '"';
        $data[] = 'data-input="#' . $this->id . '"';

        // Hidden input, where the main value is
        $value = htmlspecialchars($this->value, ENT_COMPAT, 'UTF-8');
        $str[] = '<input type="hidden" name="' . $this->name . '" id="' . $this->id . '" value="' . $value
            . '"  class="form-field-repeatable" ' . implode(' ', $data) . ' />';

        // Add scripts
        JHtml::_('bootstrap.framework');
        JHtml::_('script', 'system/repeatable.js', true, true);

        return implode("\n", $str);
    }
}
